@@ -1,3 +1,5 @@
+import time
+
 import ddtank
 
 keycode_dict = {
@@ -88,14 +90,19 @@ class Status:
         return self.name
 
     @staticmethod
-    def sleep(period: int):
+    def sleep(period: int, precise: bool = True):
         """
-        角色等待一段时间，精度高于time.sleep
+        角色等待一段时间
         :param period: 按键间隔时长(ms)
+        :param precise: 是否使用高精度计时，默认为是
         :return: 无返回值
         """
-        time_start = ddtank.time.perf_counter()
-        while ((ddtank.time.perf_counter() - time_start) * 1000) < period: continue
+        if precise:
+            time_start = ddtank.time.perf_counter()
+            while ((ddtank.time.perf_counter() - time_start) * 1000) < period:
+                continue
+        else:
+            time.sleep(period / 1000)
 
     def activate(self, period: int = 10):
         """
@@ -124,6 +131,49 @@ class Status:
         else:
             return False
 
+    def click_pixel(self, coordinate_x: int, coordinate_y: int, pixel: tuple, repeat: bool = True) -> bool:
+        """
+        当指定位置像素符合条件时，对角色模拟单击操作
+        :param coordinate_x: 单击点的x坐标
+        :param coordinate_y: 单击点的y坐标
+        :param pixel: 指定点像素的RGB值
+        :param repeat: 是否重复判断，默认为是
+        :return: 返回布尔类型变量，代表模拟信息传递是否成功
+        """
+        status_img = self.capture()
+        pixel = pixel[::-1]
+        while repeat:
+            if (status_img[coordinate_y, coordinate_x] == pixel).all():
+                self.click(coordinate_x, coordinate_y)
+                return True
+            status_img = self.capture()
+        if (status_img[coordinate_y, coordinate_x] == pixel).all():
+            self.click(coordinate_x, coordinate_y)
+            return True
+        return False
+
+    def click_pixel_back(self, coordinate_x: int, coordinate_y: int, pixel_x: int, pixel_y: int, pixel: tuple, period: int = 500) -> bool:
+        """
+        对角色模拟单击操作后等待一段时间，如果指定位置像素不符合条件时将继续模拟单击操作直到符合条件
+        :param coordinate_x: 单击点的x坐标
+        :param coordinate_y: 单击点的y坐标
+        :param pixel_x: 检测点的x坐标
+        :param pixel_y: 检测点的y坐标
+        :param pixel: 检测点像素的RGB值
+        :param period: 模拟单击操作后等待的时间(ms)
+        :return: 返回布尔类型变量，代表模拟信息传递是否成功
+        """
+        pixel = pixel[::-1]
+        self.click(coordinate_x, coordinate_y)
+        self.sleep(period)
+        status_img = self.capture()
+        while True:
+            if (status_img[pixel_y, pixel_x] == pixel).all():
+                return True
+            self.click(coordinate_x, coordinate_y)
+            self.sleep(period)
+            status_img = self.capture()
+
     def press(self, key: str, period: int = 10) -> bool:
         """
         对角色模拟按键操作
